@@ -44,7 +44,7 @@ for my $i (0 .. $#text)
 	print "0\n";
 	print "Parsing |$text|. pos: ", $parser -> pos, '. length: ', $parser -> length, "\n";
 
-	$result = $parser -> parse(\$text);
+	$result = $parser -> parse(text => \$text);
 
 	print join("\n", @{$parser -> tree -> tree2string}), "\n";
 	print "Parse result: $result (0 is success)\n";
